==> linktocontent-5.x-1.0.tar.gz: linktocontent/tinymce_plugins/linktonode/jscripts/functions.js <==
// $Id: functions.js,v 1.10.4.4 2007/03/07 08:35:24 stborchert Exp $

function preinit() {
	// Initialize
	tinyMCE.setWindowArg('mce_windowresize', false);
}

function init() {
  // load additional scripts
  loadScript("jscripts/options.js");
  loadScript("jscripts/dropdown.js");
  loadScript("jscripts/nodelist.js");
  window.focus();
  loadCategories(null);
}

/**
 * loadCategories()
 * @param obj parent Object
 **/
function loadCategories(obj) {
  var params = '';
  var vid = '-1';
  var top = 75;
  var objTop;
  if (obj != null) {
    var fSel = $("#browse_sel_0_sel");
    if (fSel !== null) {
      vid = fSel.get(0).value;
    }
    if (obj.id != 'browse_sel_0_sel') {
      params = '&ltc-term-id=' + obj.value;
    }

    try
    {
      objTop = $(obj).id().match(/_(\d+)_sel/);
      top += (objTop[1] * 17);
    }
    catch (e) {
      top += 0;
    }
  }
  params = 'ltc-type=linktocontent_node&ltc-vocab-id=' + vid + params;

  $("#statusImg").top(top + "px").show();

  $.ajax({
    type: "POST",
    url: _getBaseHref() + '?q=linktocontent',
    data: params,
    error: function(xml, msg, exc) {
      $("#statusImg").hide();
      alert('Error: ' + msg);
    },
    success: function(data){
      var results = eval('(' + data + ');');
      _clearNodeList();
      if ((obj == null) || ($(obj).get(0).value > -1)) {
        if (_fillDropdown(obj, results)) {
          window.resizeBy( 0, 17 );
        }
      }
      _fillNodelist(results);
      $("#statusImg").hide();
    }});
}

function insertAction() {
  if (selectedNode == null) {
    return;
  }
	var inst = tinyMCE.getInstanceById(tinyMCE.getWindowArg('editor_id'));
	var elm = inst.getFocusElement();

	elm = tinyMCE.getParentElement(elm, "a");

	tinyMCEPopup.execCommand("mceBeginUndoLevel");

	// Create new anchor elements
	if (elm == null) {
		var nid = selectedNode.cells[0].firstChild.nodeValue;
		var insertText = selectedNode.cells[1].firstChild.nodeValue;
    if (inst.selection.getSelectedText().length == 0) {
      tinyMCEPopup.execCommand("mceInsertContent", false,
        '<a href="' + nid + '">' + insertText + '</a>');
		}
    else {
   	  tinyMCEPopup.execCommand("mceInsertContent", false,
        '<a href="' + nid + '">' + inst.selection.getSelectedHTML() + '</a>');
    } // end (getSelectedText == 0)
	}
  else {
    elm.setAttribute("mce_href", selectedNode.cells[0].firstChild.nodeValue);
  	// Refresh in old MSIE
  	if (tinyMCE.isMSIE5)
  		elm.outerHTML = elm.outerHTML;
	}

	tinyMCE._setEventsEnabled(inst.getBody(), false);
	tinyMCEPopup.execCommand("mceEndUndoLevel");
	tinyMCEPopup.close();
}

function loadScript(url) {
  var script = document.createElement("script");
  script.type = "text/javascript";
  script.src = url;
  $("head", document).append(script);
}


/**
 * _buildUrl()
 * @param obj parent Object
 * @return requestUrl
 **/
function _buildUrl(obj){
  url = _getBaseHref() + '?q=linktocontent';

  if (obj != null) {
    var fSel = $("#browse_sel_0_sel").get(0);
    if (fSel !== null)
      url += fSel.value + "/";
    if (obj != fSel)
      url += catId = obj.value;
  }
  return url;
}

/**
 * returns the base drupal path
 * @access public
 **/
function _getBaseHref() {
  var url = tinyMCE.baseURL.substring(0, tinyMCE.baseURL.indexOf('modules/'));
  if (url.indexOf('sites/') > -1)
    url = url.substring(0, url.indexOf('sites/'));
  return url;
}

==> linktocontent-5.x-1.3.tar.gz: linktocontent/tinymce_plugins/linktonode/jscripts/functions.js <==
// $Id: functions.js,v 1.10.4.6 2007/06/03 10:34:32 stborchert Exp $

function preinit() {
	// Initialize
	tinyMCE.setWindowArg('mce_windowresize', false);
}

function init() {
  // load additional scripts
  loadScript('jscripts/options.js');
  loadScript('jscripts/dropdown.js');
  loadScript('jscripts/nodelist.js');
  window.focus();
  loadCategories(null);
}

/**
 * loadCategories()
 * @param obj parent Object
 **/
function loadCategories(obj) {
  var params = '';
  var vid = '-1';
  var top = 75;
  var objTop;
  if (obj != null) {
    var fSel = $('#browse_sel_0_sel');
    if (fSel !== null) {
      vid = $(fSel).get(0).value;
    }
    if ($(obj).attr('id') != 'browse_sel_0_sel') {
      params = '&ltc-term-id=' + $(obj).get(0).value;
    }

    try
    {
      objTop = $(obj).attr('id').match(/_(\d+)_sel/);
      top += (objTop[1] * 17);
    }
    catch (e) {
      top += 0;
    }
  }
  params = 'ltc-type=linktocontent_node&ltc-vocab-id=' + vid + params;

  $('#statusImg').css({top: top + 'px'}).show();

  $.ajax({
    type: "POST",
    url: _getBaseHref() + 'index.php?q=linktocontent',
    data: params,
    error: function(xml, msg, exc) {
      $('#statusImg').hide();
      alert('Error: ' + msg + '\n' + xml.responseText);
    },
    success: function(data){
      try {
        var results = eval('(' + data + ');');
        _clearNodeList();
        if ((obj == null) || ($(obj).get(0).value > -1)) {
          if (_fillDropdown($(obj), results)) {
            window.resizeBy( 0, 17 );
          }
        }
        _fillNodelist(results);
      }
      catch (e) {
        alert('Error on retrieving data from module.\n' + e.name + '\n' + e.message);
      } 
      finally {
        $('#statusImg').hide();
      }
    }});
}

function insertAction() {
  if (selectedNode == null) {
    return;
  }
	var inst = tinyMCE.getInstanceById(tinyMCE.getWindowArg('editor_id'));
	var elm = inst.getFocusElement();

	elm = tinyMCE.getParentElement(elm, "a");

	tinyMCEPopup.execCommand("mceBeginUndoLevel");

	// Create new anchor elements
	if (elm == null) {
		var nid = selectedNode.cells[0].firstChild.nodeValue;
		var insertText = selectedNode.cells[1].firstChild.nodeValue;
    if (inst.selection.getSelectedText().length == 0) {
      tinyMCEPopup.execCommand("mceInsertContent", false,
        '<a href="' + nid + '">' + insertText + '</a>');
		}
    else {
   	  tinyMCEPopup.execCommand("mceInsertContent", false,
        '<a href="' + nid + '">' + inst.selection.getSelectedHTML() + '</a>');
    } // end (getSelectedText == 0)
	}
  else {
    elm.setAttribute("mce_href", selectedNode.cells[0].firstChild.nodeValue);
  	// Refresh in old MSIE
  	if (tinyMCE.isMSIE5)
  		elm.outerHTML = elm.outerHTML;
	}

	tinyMCE._setEventsEnabled(inst.getBody(), false);
	tinyMCEPopup.execCommand("mceEndUndoLevel");
	tinyMCEPopup.close();
}

function loadScript(url) {
  $('head', document).append('<script type="text/javascript" src="' + url + '"></script>');
}

/**
 * returns the base drupal path
 * @access public
 **/
function _getBaseHref() {
  var url = tinyMCE.baseURL.substring(0, tinyMCE.baseURL.indexOf('modules/'));
  if (url.indexOf('sites/') > -1)
    url = url.substring(0, url.indexOf('sites/'));
  return url;
}
